@@ -19,3 +19,7 @@ def run_image(project_id: str, notebook_id: str, run_id: str, image_name: str):
     )
 
     [click.echo(line, nl=False) for line in container.logs(stream=True)]
+
+    result = container.wait()
+    if result["StatusCode"] != 0:
+        raise Exception(f"Failed! {result}")
