@@ -1,12 +1,11 @@
 import os
-import sys
 from typing import Any
 
-import click
 import docker  # type: ignore
 
 from treebeard.buildtime.helper import run_image
 from treebeard.conf import treebeard_env
+from treebeard.util import fatal_exit
 
 
 def run(project_id: str, notebook_id: str, run_id: str, image_name: str):
@@ -24,8 +23,7 @@ if __name__ == "__main__":
     image_name_key = "TREEBEARD_IMAGE_NAME"
     image_name = os.getenv(image_name_key)
     if not image_name:
-        click.echo(f"Fatal: No image supplied under {image_name_key}")
-        sys.exit(1)
+        fatal_exit(f"No image supplied under {image_name_key}")
     run(
         treebeard_env.project_id,
         treebeard_env.notebook_id,
